summaryrefslogtreecommitdiff
path: root/profile.h
diff options
context:
space:
mode:
authorChris Masone <cmasone@chromium.org>2011-07-12 13:23:59 -0700
committerChris Masone <cmasone@chromium.org>2011-07-12 13:24:19 -0700
commit7c1ab1cb74bf6397c67e1cdc825043a93c4bce33 (patch)
treeb7b5c2b4d22bfbf190e7b86c6023cf633145f4d4 /profile.h
parent9c9e8fb31c9b39fb2832e0804d5c71b3ef685427 (diff)
downloadshill-7c1ab1cb74bf6397c67e1cdc825043a93c4bce33.tar.gz
Revert "[shill] Get rid of Entry as a first-class citizen"
This reverts commit 7c982eade99f01cb6b8719ed4d385c0ec6b50f75 Change-Id: I554c12003c18f09ac7f736e98b9ecd63829100e9 Reviewed-on: http://gerrit.chromium.org/gerrit/3957 Reviewed-by: Chris Masone <cmasone@chromium.org> Tested-by: Chris Masone <cmasone@chromium.org>
Diffstat (limited to 'profile.h')
-rw-r--r--profile.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/profile.h b/profile.h
index 8b181033..89514742 100644
--- a/profile.h
+++ b/profile.h
@@ -43,10 +43,10 @@ class Profile : public base::RefCounted<Profile> {
PropertyStore *store() { return &store_; }
- // Begin managing the persistence of |service|, addressable by |name|.
- void AdoptService(const std::string &name, const ServiceRefPtr &service);
+ // Begin managing the persistence of |entry|, addressable by |entry_name|.
+ void AdoptEntry(const std::string &entry_name, const EntryRefPtr &entry);
- virtual bool MoveToActiveProfile(const std::string &name) {
+ virtual bool MoveToActiveProfile(const std::string &entry_name) {
return false;
}
@@ -74,14 +74,14 @@ class Profile : public base::RefCounted<Profile> {
// Entries representing services that are persisted to disk.
// A std::map because we will need random access for GetEntry(), but usually
- // will want to iterate over all Services.
- std::map<std::string, ServiceRefPtr> services_;
+ // will want to iterate over all Entries.
+ std::map<std::string, EntryRefPtr> entries_;
private:
friend class ProfileAdaptorInterface;
FRIEND_TEST(ProfileTest, IsValidIdentifierToken);
- // TODO(cmasone): once we can add services organically, take this out.
- FRIEND_TEST(ServiceTest, MoveService);
+ // TODO(cmasone): once we can add entries organically, take this out.
+ FRIEND_TEST(ServiceTest, MoveEntry);
static bool IsValidIdentifierToken(const std::string &token);